==> hiki-0.6.6.tar.gz: hiki-0.6.6/misc/plugin/comment.rb <==
# $Id: comment.rb,v 1.2.2.1 2004/08/06 15:45:42 fdiary Exp $
# Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>

# modified by yoshimi.

def comment_name_label
  '̾'
end

def comment_comment_label
  ''
end

def comment_post_label
  ''
end

def comment_anonymous_label
  '̵̾'
end

add_body_enter_proc(Proc.new do
  @comment_num = 0
  ""
end)

def comment(cols = 60, style = 0)
  cols = 60 unless cols.respond_to?(:integer?)
  style = 0 unless style.respond_to?(:integer?)
  style = 0 if style != 1

  @comment_num += 1
  <<EOS
<form action="#{$cgi_name}" method="post">
  <div>
    #{comment_name_label}:
    <input type="text" name="name" size="10">
    #{comment_comment_label}:
    <input type="text" name="msg" size="#{cols}">
    <input type="submit" name="comment" value="#{comment_post_label}">
    <input type="hidden" name="comment_no" value="#{@comment_num}">
    <input type="hidden" name="c" value="plugin">
    <input type="hidden" name="p" value="#{@page.escapeHTML}">
    <input type="hidden" name="plugin" value="comment_post">
    <input type="hidden" name="style" value="#{style}">
  </div>
</form>
EOS
end

def comment_post
  params     = @cgi.params
  comment_no = (params['comment_no'][0] || 0).to_i
  name       = params['name'][0].size == 0 ? comment_anonymous_label : params['name'][0]
  msg        = params['msg'][0]
  style      = params['style'][0].to_i

  return '' if msg.strip.size == 0
  
  lines = @db.load( @page )
  md5hex = @db.md5hex( @page )
  
  flag = false
  count = 1

  content = ''
  lines.each do |l|
    if /^\{\{comment.*\}\}/ =~ l && flag == false
      if count == comment_no
        content << l if style == 1
        content << "*#{format_date(Time::now)} \'\'[[#{name}]]\'\' : #{msg}\n"
        content << l if style == 0
        flag = true
      else
        count += 1
        content << l
      end
    else
      content << l
    end
  end
  
  @db.save( @page, content, md5hex ) if flag
end

==> hiki-0.8.0.tar.gz: hiki-0.8.0/misc/plugin/comment.rb <==
# $Id: comment.rb,v 1.9 2005/06/29 04:26:39 fdiary Exp $
# Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>

# modified by yoshimi.

add_body_enter_proc(Proc.new do
  @comment_num = 0
  ""
end)

def comment(cols = 60, style = 0)
  cols = 60 unless cols.respond_to?(:integer?)
  style = 0 unless style.respond_to?(:integer?)
  style = 0 if style != 1

  @comment_num += 1
  name = @cgi.cookies['auth_name'][0] || ''
  <<EOS
<form action="#{@conf.cgi_name}" method="post">
  <div>
    #{comment_name_label}:
    <input type="text" name="name" value="#{name}" size="10">
    #{comment_comment_label}:
    <input type="text" name="msg" size="#{cols}">
    <input type="submit" name="comment" value="#{comment_post_label}">
    <input type="hidden" name="comment_no" value="#{@comment_num}">
    <input type="hidden" name="c" value="plugin">
    <input type="hidden" name="p" value="#{@page.escapeHTML}">
    <input type="hidden" name="plugin" value="comment_post">
    <input type="hidden" name="style" value="#{style}">
  </div>
</form>
EOS
end

def comment_post
  params     = @cgi.params
  comment_no = (params['comment_no'][0] || 0).to_i
  name       = params['name'][0].size == 0 ? comment_anonymous_label : params['name'][0]
  msg        = params['msg'][0]
  style      = params['style'][0].to_i

  return '' if msg.strip.size == 0
  
  lines = @db.load( @page )
  md5hex = @db.md5hex( @page )
  
  flag = false
  count = 1

  content = ''
  lines.each do |l|
    if /^\{\{r?comment.*\}\}/ =~ l && flag == false
      if count == comment_no
        content << l if style == 1
        content << "*#{format_date(Time::now)} #{name} : #{msg}\n"
        content << l if style == 0
        flag = true
      else
        count += 1
        content << l
      end
    else
      content << l
    end
  end
  
  save( @page, content, md5hex ) if flag
end

def rcomment(cols = 60)
  comment(cols, 1)
end
